@@ -4,7 +4,7 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 our $USE_NONCORE_XS_FIRST = 1;
 
@@ -12,6 +12,7 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(
                        clone
+                       unbless
                        uniq
                );
 
@@ -28,6 +29,41 @@ sub clone {
     return Clone::PP::clone($data);
 }
 
+sub _unbless_fallback {
+    my $ref = shift;
+
+    my $r = ref($ref);
+    # not a reference
+    return $ref unless $r;
+
+    # return if not a blessed ref
+    my ($r2, $r3) = "$ref" =~ /(.+)=(.+?)\(/
+        or return $ref;
+
+    if ($r3 eq 'HASH') {
+        return { %$ref };
+    } elsif ($r3 eq 'ARRAY') {
+        return [ @$ref ];
+    } elsif ($r3 eq 'SCALAR') {
+        return \( my $copy = ${$ref} );
+    } else {
+        die "Can't handle $ref";
+    }
+}
+
+sub unbless {
+    my $ref = shift;
+
+    goto FALLBACK unless $USE_NONCORE_XS_FIRST;
+    goto FALLBACK unless eval { require Acme::Damn; 1 };
+
+  STANDARD:
+    return Acme::Damn::damn($ref);
+
+  FALLBACK:
+    return _unbless_fallback($ref);
+}
+
 sub uniq {
     goto FALLBACK unless $USE_NONCORE_XS_FIRST;
     goto FALLBACK unless eval { require List::MoreUtils; 1 };
@@ -59,13 +95,14 @@ Function::Fallback::CoreOrPP - Functions that use non-core XS module but provide
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
- use Function::Fallback::CoreOrPP qw(clone uniq);
+ use Function::Fallback::CoreOrPP qw(clone unbless uniq);
 
  my $clone = clone({blah=>1});
+ my $unblessed = unbless($blessed_ref);
  my @uniq  = uniq(1, 3, 2, 1, 4);  # -> (1, 3, 2, 4)
 
 =head1 DESCRIPTION
@@ -85,8 +122,20 @@ dependencies to your script.
 
 =head2 clone($data) => $cloned
 
-Try to use L<Data::Clone>'s C<clone> (because it's the fastest) but, when not
-available, fall back to L<Clone::PP>'s C<clone>.
+Try to use L<Data::Clone>'s C<clone>, but fall back to using L<Clone::PP>'s
+C<clone>.
+
+=head2 unbless($ref) => $unblessed_ref
+
+Try to use L<Acme::Damn>'s C<damn> to unbless a reference but fall back to
+shallow copying.
+
+NOTE: C<damn()> B<MODIFIES> the original reference. (XXX in the future an option
+to clone the reference first will be provided), while shallow copying will
+return a shallow copy.
+
+NOTE: The shallow copy method currently only handles blessed
+{scalar,array,hash}ref as those are the most common.
 
 =head2 uniq(@ary) => @uniq_ary
 
